File

Struct File 

pub struct File {
    pub name: String,
    pub path: PathBuf,
    pub is_dir: bool,
    pub is_hidden: bool,
    pub file_type: Option<FileType>,
}
A file or directory in the file explorer.

Fields

name: String

The name of the file or directory.

Examples

Suppose you have this tree file, with passport.png selected inside file_explorer:

/
├── .git
└── Documents
    ├── passport.png  <- selected
    └── resume.pdf

You can get the name of the selected file like this:

use ratatui_explorer::FileExplorer;

let file_explorer = FileExplorer::new().unwrap();

/* user select `password.png` */

let file = file_explorer.current();
assert_eq!(file.name, "passport.png");
path: PathBuf

Returns the path of the file or directory.

Examples

Suppose you have this tree file, with passport.png selected inside file_explorer:

/
├── .git
└── Documents
    ├── passport.png  <- selected
    └── resume.pdf

You can get the path of the selected file like this:

use ratatui_explorer::FileExplorer;

let file_explorer = FileExplorer::new().unwrap();

/* user select `password.png` */

let file = file_explorer.current();
assert_eq!(file.path.display().to_string(), "/Documents/passport.png");
is_dir: bool

Is true is the file is a directory.

Examples

Suppose you have this tree file, with passport.png selected inside file_explorer:

/
├── .git
└── Documents
    ├── passport.png  <- selected
    └── resume.pdf

You can know if the selected file is a directory like this:

use ratatui_explorer::FileExplorer;

let file_explorer = FileExplorer::new().unwrap();

/* user select `password.png` */

let file = file_explorer.current();
assert_eq!(file.is_dir, false);

/* user select `Documents` */

let file = file_explorer.current();
assert_eq!(file.is_dir, true);
is_hidden: bool

Is true if the file or directory is hidden.

Examples

Suppose you have this tree file, with passport.png selected inside file_explorer:

/
├── .git
└── Documents
    ├── passport.png  <- selected
    └── resume.pdf

You can know if the selected file or directory is hidden like this:

use ratatui_explorer::FileExplorer;

let mut file_explorer = FileExplorer::new().unwrap();
file_explorer.set_show_hidden(true);

/* user select `password.png` */

let file = file_explorer.current();
assert_eq!(file.is_hidden, false);

/* user select `.git` */

let file = file_explorer.current();
assert_eq!(file.is_hidden, true);
file_type: Option<FileType>

The FileType of the file, when available.

Examples

Suppose you have this tree file, with passport.png selected inside file_explorer:

/
├── .git
└── Documents
    ├── passport.png  <- selected
    └── resume.pdf

You can know if the selected file is a directory like this:

use ratatui_explorer::FileExplorer;

let file_explorer = FileExplorer::new().unwrap();

/* user select `password.png` */

let file = file_explorer.current();
assert_eq!(file.file_type.unwrap().is_dir(), false);

/* user select `Documents` */

let file = file_explorer.current();
assert_eq!(file.file_type.unwrap().is_dir(), true);

Implementations

Source

impl File

pub fn is_file(&self) -> bool

Returns true is the file is a regular file.

Examples

Suppose you have this tree file, with passport.png selected inside file_explorer:

/
├── .git
└── Documents
    ├── passport.png  <- selected
    └── resume.pdf

You can know if the selected file is a directory like this:

use ratatui_explorer::FileExplorer;

let file_explorer = FileExplorer::new().unwrap();

/* user select `password.png` */

let file = file_explorer.current();
assert_eq!(file.is_file(), true);

/* user select `Documents` */

let file = file_explorer.current();
assert_eq!(file.is_file(), false);
pub fn name(&self) -> &str

👎Deprecated since 0.3.0:

name field is public and should be acceded with .name

pub const fn path(&self) -> &PathBuf

👎Deprecated since 0.3.0:

path field is public and should be acceded with .path

pub const fn is_dir(&self) -> bool

👎Deprecated since 0.3.0:

is_dir field is public and should be acceded with .is_dir

pub fn is_hidden(&self) -> bool

👎Deprecated since 0.3.0:

is_hidden field is public and should be acceded with .is_hidden

pub const fn file_type(&self) -> Option<FileType>

👎Deprecated since 0.3.0:

file_type field is public and should be acceded with .file_type