pub struct File {
pub name: String,
pub path: PathBuf,
pub is_dir: bool,
pub is_hidden: bool,
pub file_type: Option<FileType>,
}Expand description
A file or directory in the file explorer.
Fields
name: StringThe name of the file or directory.
Examples
Suppose you have this tree file, with passport.png selected inside file_explorer:
/
├── .git
└── Documents
├── passport.png <- selected
└── resume.pdfYou can get the name of the selected file like this:
use ratatui_explorer::FileExplorer;
let file_explorer = FileExplorer::new().unwrap();
/* user select `password.png` */
let file = file_explorer.current();
assert_eq!(file.name, "passport.png");path: PathBufReturns the path of the file or directory.
Examples
Suppose you have this tree file, with passport.png selected inside file_explorer:
/
├── .git
└── Documents
├── passport.png <- selected
└── resume.pdfYou can get the path of the selected file like this:
use ratatui_explorer::FileExplorer;
let file_explorer = FileExplorer::new().unwrap();
/* user select `password.png` */
let file = file_explorer.current();
assert_eq!(file.path.display().to_string(), "/Documents/passport.png");is_dir: boolIs true is the file is a directory.
Examples
Suppose you have this tree file, with passport.png selected inside file_explorer:
/
├── .git
└── Documents
├── passport.png <- selected
└── resume.pdfYou can know if the selected file is a directory like this:
use ratatui_explorer::FileExplorer;
let file_explorer = FileExplorer::new().unwrap();
/* user select `password.png` */
let file = file_explorer.current();
assert_eq!(file.is_dir, false);
/* user select `Documents` */
let file = file_explorer.current();
assert_eq!(file.is_dir, true);Is true if the file or directory is hidden.
Examples
Suppose you have this tree file, with passport.png selected inside file_explorer:
/
├── .git
└── Documents
├── passport.png <- selected
└── resume.pdfYou can know if the selected file or directory is hidden like this:
use ratatui_explorer::FileExplorer;
let mut file_explorer = FileExplorer::new().unwrap();
file_explorer.set_show_hidden(true);
/* user select `password.png` */
let file = file_explorer.current();
assert_eq!(file.is_hidden, false);
/* user select `.git` */
let file = file_explorer.current();
assert_eq!(file.is_hidden, true);file_type: Option<FileType>The FileType of the file, when available.
Examples
Suppose you have this tree file, with passport.png selected inside file_explorer:
/
├── .git
└── Documents
├── passport.png <- selected
└── resume.pdfYou can know if the selected file is a directory like this:
use ratatui_explorer::FileExplorer;
let file_explorer = FileExplorer::new().unwrap();
/* user select `password.png` */
let file = file_explorer.current();
assert_eq!(file.file_type.unwrap().is_dir(), false);
/* user select `Documents` */
let file = file_explorer.current();
assert_eq!(file.file_type.unwrap().is_dir(), true);Implementations
Sourceimpl File
impl File
Sourcepub fn is_file(&self) -> bool
pub fn is_file(&self) -> bool
Returns true is the file is a regular file.
Examples
Suppose you have this tree file, with passport.png selected inside file_explorer:
/
├── .git
└── Documents
├── passport.png <- selected
└── resume.pdfYou can know if the selected file is a directory like this:
use ratatui_explorer::FileExplorer;
let file_explorer = FileExplorer::new().unwrap();
/* user select `password.png` */
let file = file_explorer.current();
assert_eq!(file.is_file(), true);
/* user select `Documents` */
let file = file_explorer.current();
assert_eq!(file.is_file(), false);pub fn name(&self) -> &str
name field is public and should be acceded with .name
pub const fn path(&self) -> &PathBuf
path field is public and should be acceded with .path
pub const fn is_dir(&self) -> bool
is_dir field is public and should be acceded with .is_dir
is_hidden field is public and should be acceded with .is_hidden
pub const fn file_type(&self) -> Option<FileType>
file_type field is public and should be acceded with .file_type