FileExplorerBuilder

Struct FileExplorerBuilder 

pub struct FileExplorerBuilder { /* private fields */ }
Builder for creating a FileExplorer.

By default, the builder create FileExplorer with a working directory set to the current one.

Implementations

Source

impl FileExplorerBuilder

pub fn working_dir<P: Into<PathBuf>>(self, working_dir: P) -> Self

Set the current working directory for the FileExplorer. If not set, it defaults to the current directory.

Examples

Suppose you have this tree file:

/
├── .git
└── Documents
    ├── passport.png
    └── resume.pdf

You can create a new FileExplorer like this:

let file_explorer = FileExplorerBuilder::default()
    .working_dir("/Documents")
    .build()
    .unwrap();

assert_eq!(file_explorer.cwd().display().to_string(), "/Documents");
pub fn working_file<P: Into<PathBuf>>(self, working_file: P) -> Self

Same as working_dir but will pre-select the file in the working directory.

This method set the working directory to the parent directory of the provided file and select the file in the file explorer. You can also select a directory (eg. select /Documents inside /).

Examples

Suppose you have this tree file:

/
├── .git
└── Documents
    ├── passport.png
    └── resume.pdf

You can create a new FileExplorer selecting passport.png like this:

let file_explorer = FileExplorerBuilder::default()
    .working_file("/Documents/passport.png")
    .build()
    .unwrap();

assert_eq!(file_explorer.cwd().display().to_string(), "/Documents");
assert_eq!(file_explorer.current().path.display().to_string(), "/Documents/passport.png");
pub fn show_hidden(self, show: bool) -> Self

Set whether to show hidden files in the FileExplorer. Defaults to false.

pub fn filter_map( self, f: impl Fn(File) -> Option<File> + Send + Sync + 'static, ) -> Self

Set a filter and map for the FileExplorer.

If not set, all files are shown. Hidden files are filtered before this filter will be apply.

Examples
let file_explorer = FileExplorerBuilder::default()
    .filter_map(|file| if file.is_dir { Some(file) } else { None })
    .build()
    .unwrap();

/* Only directories are shown */
pub fn theme(self, theme: Theme) -> Self

Set the theme for the FileExplorer. If not set, it defaults to Theme::new.

Examples
let file_explorer = FileExplorerBuilder::default()
    .theme(Theme::default().add_default_title())
    .build()
    .unwrap();
pub fn build(self) -> Result<FileExplorer>

Build the FileExplorer instance based on the provided configuration.

Errors

Will return Err if the setted working directory can not be listed.

Will return Err if NO working directory have been setted and current working directory can not be listed. See current_dir for more information.

pub fn build_with_theme(theme: Theme) -> Result<FileExplorer>

Shortcut method to create a FileExplorer with a custom theme. See theme for more information about the theme configuration.

pub fn build_with_working_dir<P: Into<PathBuf>>( working_dir: P, ) -> Result<FileExplorer>

Shortcut method to create a FileExplorer with a custom working directory. See working_dir for more information about the working directory configuration.

pub fn build_with_working_file<P: Into<PathBuf>>( working_dir: P, ) -> Result<FileExplorer>

Shortcut method to create a FileExplorer with a custom working directory and file. See working_file for more information about the working directory configuration.